@@ -72,7 +72,7 @@ DIALOG_LIB_SYMBOL_PROPERTIES::DIALOG_LIB_SYMBOL_PROPERTIES( SYMBOL_EDIT_FRAME* a
     m_grid->ShowHideColumns( cfg->m_EditSymbolVisibleColumns );
 
     wxGridCellAttr* attr = new wxGridCellAttr;
-    attr->SetEditor( new GRID_CELL_URL_EDITOR( this ) );
+    attr->SetEditor( new GRID_CELL_URL_EDITOR( this, Prj().SchSearchS() ) );
     m_grid->SetAttr( DATASHEET_FIELD, FDC_VALUE, attr );
 
     m_SymbolNameCtrl->SetValidator( SCH_FIELD_VALIDATOR( true, VALUE_FIELD ) );
@@ -174,7 +174,13 @@ bool DIALOG_LIB_SYMBOL_PROPERTIES::TransferDataToWindow()
     m_SelNumberOfUnits->SetValue( m_libEntry->GetUnitCount() );
     m_OptionPartsInterchangeable->SetValue( !m_libEntry->UnitsLocked() ||
                                             m_libEntry->GetUnitCount() == 1 );
-    m_AsConvertButt->SetValue( m_libEntry->HasConversion() );
+
+    // If a symbol contains no conversion-specific pins or graphic items, symbol->HasConversion()
+    // will return false.  But when editing a symbol with DeMorgan option set, we don't want to
+    // keep turning it off just because there aren't any conversion-specific items yet, so we force
+    // it to on if the parent frame has it enabled.
+    m_AsConvertButt->SetValue( m_Parent->GetShowDeMorgan() );
+
     m_OptionPower->SetValue( m_libEntry->IsPower() );
     m_excludeFromBomCheckBox->SetValue( !m_libEntry->GetIncludeInBom() );
     m_excludeFromBoardCheckBox->SetValue( !m_libEntry->GetIncludeOnBoard() );
@@ -367,6 +373,7 @@ bool DIALOG_LIB_SYMBOL_PROPERTIES::TransferDataFromWindow()
     m_libEntry->LockUnits( m_libEntry->GetUnitCount() > 1 &&
                            !m_OptionPartsInterchangeable->GetValue() );
     m_libEntry->SetConversion( m_AsConvertButt->GetValue() );
+    m_Parent->SetShowDeMorgan( m_AsConvertButt->GetValue() );
 
     if( m_OptionPower->GetValue() )
         m_libEntry->SetPower();
@@ -448,7 +455,7 @@ void DIALOG_LIB_SYMBOL_PROPERTIES::OnGridCellChanging( wxGridEvent& event )
 
 void DIALOG_LIB_SYMBOL_PROPERTIES::OnSymbolNameText( wxCommandEvent& event )
 {
-    if( !m_Parent->IsSymbolFromSchematic() )
+    if( !m_Parent->IsSymbolFromSchematic() || m_OptionPower->IsChecked() )
         m_grid->SetCellValue( VALUE_FIELD, FDC_VALUE, m_SymbolNameCtrl->GetValue() );
 }
 
@@ -464,7 +471,10 @@ void DIALOG_LIB_SYMBOL_PROPERTIES::OnSymbolNameKillFocus( wxFocusEvent& event )
         m_delayedFocusPage = 0;
 
         if( m_SymbolNameCtrl->GetValidator()->Validate( m_SymbolNameCtrl ) )
+        {
             m_delayedFocusCtrl = nullptr;
+            m_delayedFocusPage = -1;
+        }
     }
 
     event.Skip();
