@@ -2,7 +2,7 @@
  * This program source code file is part of KiCad, a free EDA CAD application.
  *
  * Copyright (C) 2015 Chris Pavlina <pavlina.chris@gmail.com>
- * Copyright (C) 2015-2021 KiCad Developers, see change_log.txt for contributors.
+ * Copyright (C) 2015-2022 KiCad Developers, see change_log.txt for contributors.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -34,6 +34,7 @@
 #include <sch_sheet.h>
 #include <sch_edit_frame.h>
 #include <schematic.h>
+#include <string_utils.h>
 #include <symbol_lib_table.h>
 #include <wildcards_and_files_ext.h>
 
@@ -89,7 +90,6 @@ static void getSymbols( SCHEMATIC* aSchematic, std::vector<SCH_SYMBOL*>& aSymbol
 static LIB_SYMBOL* findSymbol( const wxString& aName, SYMBOL_LIBS* aLibs, bool aCached )
 {
     LIB_SYMBOL *symbol = nullptr;
-    // wxString new_name = LIB_ID::FixIllegalChars( aName, false );
 
     for( SYMBOL_LIB& each_lib : *aLibs )
     {
@@ -150,7 +150,7 @@ void RESCUE_CASE_CANDIDATE::FindRescues( RESCUER& aRescuer,
     for( SCH_SYMBOL* eachSymbol : *( aRescuer.GetSymbols() ) )
     {
         symbol_name = eachSymbol->GetLibId().GetLibItemName();
-        search_name = LIB_ID::FixIllegalChars( symbol_name, false );
+        search_name = EscapeString ( symbol_name, CTX_LIBID );
 
         if( last_symbol_name != symbol_name )
         {
@@ -255,7 +255,7 @@ void RESCUE_CACHE_CANDIDATE::FindRescues( RESCUER& aRescuer,
     for( SCH_SYMBOL* eachSymbol : *( aRescuer.GetSymbols() ) )
     {
         symbol_name = eachSymbol->GetLibId().GetLibItemName();
-        search_name = LIB_ID::FixIllegalChars( symbol_name, false );
+        search_name = EscapeString ( symbol_name, CTX_LIBID );
 
         if( old_symbol_name != symbol_name )
         {
@@ -316,7 +316,7 @@ bool RESCUE_CACHE_CANDIDATE::PerformAction( RESCUER* aRescuer )
 {
     LIB_SYMBOL* tmp = ( m_cache_candidate ) ? m_cache_candidate : m_lib_candidate;
 
-    wxCHECK_MSG( tmp, false, "Both cache and library symbols undefined." );
+    wxCHECK_MSG( tmp, false, wxT( "Both cache and library symbols undefined." ) );
 
     std::unique_ptr<LIB_SYMBOL> new_symbol = tmp->Flatten();
     new_symbol->SetName( m_new_name );
@@ -378,6 +378,8 @@ void RESCUE_SYMBOL_LIB_TABLE_CANDIDATE::FindRescues(
     LIB_SYMBOL* lib_match = nullptr;
     LIB_ID old_symbol_id;
 
+    wxString escapedSymbolName;
+
     for( SCH_SYMBOL* eachSymbol : *( aRescuer.GetSymbols() ) )
     {
         const LIB_ID& symbol_id = eachSymbol->GetLibId();
@@ -388,11 +390,25 @@ void RESCUE_SYMBOL_LIB_TABLE_CANDIDATE::FindRescues(
             // Search the symbol names candidates only once for this group:
             old_symbol_id = symbol_id;
 
+            escapedSymbolName = EscapeString( symbol_id.Format().wx_str(), CTX_LIBID );
+
             // Get the library symbol from the cache library.  It will be a flattened
             // symbol by default (no inheritance).
-            cache_match = findSymbol( symbol_id.Format().wx_str(), aRescuer.GetPrj()->SchLibs(),
+            cache_match = findSymbol( escapedSymbolName, aRescuer.GetPrj()->SchLibs(),
                                       true );
 
+            // At some point during V5 development, the LIB_ID delimiter character ':' was
+            // replaced by '_' when writing the symbol cache library so we have to test for
+            // the LIB_NICKNAME_LIB_SYMBOL_NAME case.
+            if( !cache_match )
+            {
+                escapedSymbolName = EscapeString( symbol_id.GetLibNickname().wx_str() +
+                                                  wxT( "_" ) + symbol_id.GetLibItemName().wx_str(),
+                                                  CTX_LIBID );
+                cache_match = findSymbol( escapedSymbolName, aRescuer.GetPrj()->SchLibs(),
+                                          true );
+            }
+
             // Get the library symbol from the symbol library table.
             lib_match = SchGetLibSymbol( symbol_id, aRescuer.GetPrj()->SchSymbolLibTable() );
 
@@ -434,8 +450,8 @@ void RESCUE_SYMBOL_LIB_TABLE_CANDIDATE::FindRescues(
 
             // Spaces in the file name will break the symbol name because they are not
             // quoted in the symbol library file format.
-            libNickname.Replace( " ", "-" );
-            LIB_ID new_id( libNickname, new_name + "-" + symbol_id.GetLibNickname().wx_str() );
+            libNickname.Replace( wxT( " " ), wxT( "-" ) );
+            LIB_ID new_id( libNickname, new_name + wxT( "-" ) + symbol_id.GetLibNickname().wx_str() );
 
             RESCUE_SYMBOL_LIB_TABLE_CANDIDATE candidate( symbol_id, new_id, cache_match, lib_match,
                                                          eachSymbol->GetUnit(),
@@ -484,7 +500,7 @@ bool RESCUE_SYMBOL_LIB_TABLE_CANDIDATE::PerformAction( RESCUER* aRescuer )
 {
     LIB_SYMBOL* tmp = ( m_cache_candidate ) ? m_cache_candidate : m_lib_candidate;
 
-    wxCHECK_MSG( tmp, false, "Both cache and library symbols undefined." );
+    wxCHECK_MSG( tmp, false, wxT( "Both cache and library symbols undefined." ) );
 
     std::unique_ptr<LIB_SYMBOL> new_symbol = tmp->Flatten();
     new_symbol->SetLibId( m_new_id );
@@ -761,7 +777,7 @@ bool LEGACY_RESCUER::WriteRescueLibrary( wxWindow *aParent )
 
 void LEGACY_RESCUER::AddSymbol( LIB_SYMBOL* aNewSymbol )
 {
-    wxCHECK_RET( aNewSymbol, "Invalid LIB_SYMBOL pointer." );
+    wxCHECK_RET( aNewSymbol, wxT( "Invalid LIB_SYMBOL pointer." ) );
 
     aNewSymbol->SetLib( m_rescue_lib.get() );
     m_rescue_lib->AddSymbol( aNewSymbol );
@@ -817,15 +833,15 @@ bool SYMBOL_LIB_TABLE_RESCUER::WriteRescueLibrary( wxWindow *aParent )
             return false;
         }
 
-        wxString uri = "${KIPRJMOD}/" + fn.GetFullName();
+        wxString uri = wxT( "${KIPRJMOD}/" ) + fn.GetFullName();
         wxString libNickname = fn.GetName();
 
         // Spaces in the file name will break the symbol name because they are not
         // quoted in the symbol library file format.
-        libNickname.Replace( " ", "-" );
+        libNickname.Replace( wxT( " " ), wxT( "-" ) );
 
         SYMBOL_LIB_TABLE_ROW* row = new SYMBOL_LIB_TABLE_ROW( libNickname, uri,
-                                                              wxString( "Legacy" ) );
+                                                              wxString( wxT( "Legacy" ) ) );
         m_prj->SchSymbolLibTable()->InsertRow( row );
 
         fn = wxFileName( m_prj->GetProjectPath(), SYMBOL_LIB_TABLE::GetSymbolLibTableFileName() );
@@ -858,7 +874,7 @@ bool SYMBOL_LIB_TABLE_RESCUER::WriteRescueLibrary( wxWindow *aParent )
 
 void SYMBOL_LIB_TABLE_RESCUER::AddSymbol( LIB_SYMBOL* aNewSymbol )
 {
-    wxCHECK_RET( aNewSymbol, "Invalid LIB_SYMBOL pointer." );
+    wxCHECK_RET( aNewSymbol, wxT( "Invalid LIB_SYMBOL pointer." ) );
 
     wxFileName fn = GetRescueLibraryFileName( m_schematic );
 
