@@ -88,6 +88,7 @@ int SCH_MOVE_TOOL::Main( const TOOL_EVENT& aEvent )
     KIGFX::VIEW_CONTROLS* controls = getViewControls();
     EE_GRID_HELPER        grid( m_toolMgr );
     bool                  wasDragging = m_moveInProgress && m_isDrag;
+    SCH_MOVE_TOOL_PARAMS* params = aEvent.Parameter<SCH_MOVE_TOOL_PARAMS*>();
 
     m_anchorPos.reset();
 
@@ -174,8 +175,11 @@ int SCH_MOVE_TOOL::Main( const TOOL_EVENT& aEvent )
             if( !m_moveInProgress )    // Prepare to start moving/dragging
             {
                 SCH_ITEM* sch_item = (SCH_ITEM*) selection.Front();
-                bool      appendUndo = sch_item && sch_item->IsNew();
-                bool      placingNewItems = sch_item && sch_item->IsNew();
+                bool      appendUndo =
+                        params ? params->appendToLastUndo : ( sch_item && sch_item->IsNew() );
+                bool placingNewItems =
+                        params ? params->placingNewItems : ( sch_item && sch_item->IsNew() );
+
 
                 //------------------------------------------------------------------------
                 // Setup a drag or a move
@@ -380,6 +384,9 @@ int SCH_MOVE_TOOL::Main( const TOOL_EVENT& aEvent )
         //
         else if( evt->IsCancelInteractive() || evt->IsActivate() )
         {
+            if( evt->IsCancelInteractive() )
+                m_frame->GetInfoBar()->Dismiss();
+
             if( m_moveInProgress )
             {
                 if( evt->IsActivate() )
@@ -446,6 +453,11 @@ int SCH_MOVE_TOOL::Main( const TOOL_EVENT& aEvent )
                 }
             }
         }
+        else if( evt->IsAction( &EE_ACTIONS::highlightNet )
+                    || evt->IsAction( &EE_ACTIONS::explicitCrossProbe ) )
+        {
+            // These don't make any sense during a move.  Eat them.
+        }
         //------------------------------------------------------------------------
         // Handle context menu
         //
@@ -505,6 +517,7 @@ int SCH_MOVE_TOOL::Main( const TOOL_EVENT& aEvent )
                 m_frame->AddJunction( m_frame->GetScreen(), it.GetPosition(), true, false );
         }
 
+        m_toolMgr->RunAction( EE_ACTIONS::trimOverlappingWires, true, &selectionCopy );
         m_toolMgr->RunAction( EE_ACTIONS::addNeededJunctions, true, &selectionCopy );
 
         m_frame->RecalculateConnections( LOCAL_CLEANUP );
@@ -740,8 +753,8 @@ void SCH_MOVE_TOOL::moveItem( EDA_ITEM* aItem, const VECTOR2I& aDelta )
         if( aItem->HasFlag( ENDPOINT ) )
             line->MoveEnd( (wxPoint) aDelta );
 
-    }
         break;
+    }
 
     case SCH_PIN_T:
     case SCH_FIELD_T:
@@ -765,13 +778,16 @@ void SCH_MOVE_TOOL::moveItem( EDA_ITEM* aItem, const VECTOR2I& aDelta )
 
         break;
     }
+
     case SCH_SHEET_PIN_T:
     {
         SCH_SHEET_PIN* pin = (SCH_SHEET_PIN*) aItem;
+
         pin->SetStoredPos( pin->GetStoredPos() + (wxPoint) aDelta );
         pin->ConstrainOnEdge( pin->GetStoredPos() );
         break;
     }
+
     case SCH_LABEL_T:
     {
         SCH_TEXT* label = static_cast<SCH_TEXT*>( aItem );
@@ -789,6 +805,7 @@ void SCH_MOVE_TOOL::moveItem( EDA_ITEM* aItem, const VECTOR2I& aDelta )
 
         break;
     }
+
     default:
         static_cast<SCH_ITEM*>( aItem )->Move( (wxPoint) aDelta );
         break;
@@ -805,6 +822,17 @@ int SCH_MOVE_TOOL::AlignElements( const TOOL_EVENT& aEvent )
     EE_SELECTION& selection = m_selectionTool->RequestSelection( EE_COLLECTOR::MovableItems );
     bool append_undo = false;
 
+    auto doMoveItem =
+            [&]( EDA_ITEM* item, const VECTOR2I& delta )
+            {
+                saveCopyInUndoList( item, UNDO_REDO::CHANGED, append_undo );
+                append_undo = true;
+
+                moveItem( item, delta );
+                item->ClearFlags( IS_MOVING );
+                updateItem( item, true );
+            };
+
     for( SCH_ITEM* it : m_frame->GetScreen()->Items() )
     {
         if( !it->IsSelected() )
@@ -848,12 +876,7 @@ int SCH_MOVE_TOOL::AlignElements( const TOOL_EVENT& aEvent )
                         if( dragItem->GetParent() && dragItem->GetParent()->IsSelected() )
                             continue;
 
-                        saveCopyInUndoList( dragItem, UNDO_REDO::CHANGED, append_undo );
-                        append_undo = true;
-
-                        moveItem( dragItem, gridpt );
-                        dragItem->ClearFlags( IS_MOVING );
-                        updateItem( dragItem, true );
+                        doMoveItem( dragItem, gridpt );
                     }
                 }
             }
@@ -863,13 +886,49 @@ int SCH_MOVE_TOOL::AlignElements( const TOOL_EVENT& aEvent )
             VECTOR2I gridpt = grid.AlignGrid( item->GetPosition() ) - item->GetPosition();
 
             if( gridpt != VECTOR2I( 0, 0 ) )
-            {
-                saveCopyInUndoList( item, UNDO_REDO::CHANGED, append_undo );
-                append_undo = true;
+                doMoveItem( item, gridpt );
+        }
+        else if( item->Type() == SCH_SHEET_T )
+        {
+            SCH_SHEET* sheet = static_cast<SCH_SHEET*>( item );
+            VECTOR2I   topRight = sheet->GetPosition();
+            VECTOR2I   bottomRight = topRight + sheet->GetSize();
+            VECTOR2I   tl_gridpt = grid.AlignGrid( topRight ) - topRight;
+            VECTOR2I   br_gridpt = grid.AlignGrid( bottomRight ) - bottomRight;
 
-                moveItem( item, gridpt );
-                updateItem( item, true );
-                item->ClearFlags( IS_MOVING );
+            if( tl_gridpt != VECTOR2I( 0, 0 ) || br_gridpt != VECTOR2I( 0, 0 ) )
+            {
+                doMoveItem( sheet, tl_gridpt );
+
+                VECTOR2I newSize = (VECTOR2I) sheet->GetSize() - tl_gridpt + br_gridpt;
+                sheet->SetSize( wxSize( newSize.x, newSize.y ) );
+                updateItem( sheet, true );
+
+                for( SCH_SHEET_PIN* pin : sheet->GetPins() )
+                {
+                    VECTOR2I gridpt;
+
+                    if( pin->GetSide() == SHEET_SIDE::TOP || pin->GetSide() == SHEET_SIDE::LEFT )
+                        gridpt = tl_gridpt;
+                    else
+                        gridpt = br_gridpt;
+
+                    if( gridpt != VECTOR2I( 0, 0 ) )
+                    {
+                        EDA_ITEMS drag_items;
+                        getConnectedDragItems( pin, pin->GetConnectionPoints()[0], drag_items );
+
+                        doMoveItem( pin, gridpt );
+
+                        for( EDA_ITEM* dragItem : drag_items )
+                        {
+                            if( dragItem->GetParent() && dragItem->GetParent()->IsSelected() )
+                                continue;
+
+                            doMoveItem( dragItem, gridpt );
+                        }
+                    }
+                }
             }
         }
         else
@@ -905,18 +964,14 @@ int SCH_MOVE_TOOL::AlignElements( const TOOL_EVENT& aEvent )
                     if( dragItem->GetParent() && dragItem->GetParent()->IsSelected() )
                         continue;
 
-                    saveCopyInUndoList( dragItem, UNDO_REDO::CHANGED, append_undo );
-                    append_undo = true;
-
-                    moveItem( dragItem, most_common );
-                    dragItem->ClearFlags( IS_MOVING );
-                    updateItem( dragItem, true );
+                    doMoveItem( dragItem, most_common );
                 }
             }
         }
     }
 
     m_toolMgr->PostEvent( EVENTS::SelectedItemsMoved );
+    m_toolMgr->RunAction( EE_ACTIONS::trimOverlappingWires, true, &selection );
     m_toolMgr->RunAction( EE_ACTIONS::addNeededJunctions, true, &selection );
 
     m_frame->RecalculateConnections( LOCAL_CLEANUP );
