@@ -464,7 +464,7 @@ int PCB_SELECTION_TOOL::Main( const TOOL_EVENT& aEvent )
 void PCB_SELECTION_TOOL::EnterGroup()
 {
     wxCHECK_RET( m_selection.GetSize() == 1 && m_selection[0]->Type() == PCB_GROUP_T,
-                 "EnterGroup called when selection is not a single group" );
+                 wxT( "EnterGroup called when selection is not a single group" ) );
     PCB_GROUP* aGroup = static_cast<PCB_GROUP*>( m_selection[0] );
 
     if( m_enteredGroup != nullptr )
@@ -922,6 +922,11 @@ bool PCB_SELECTION_TOOL::selectMultiple()
 
 int PCB_SELECTION_TOOL::disambiguateCursor( const TOOL_EVENT& aEvent )
 {
+    wxMouseState keyboardState = wxGetMouseState();
+
+    setModifiersState( keyboardState.ShiftDown(), keyboardState.ControlDown(),
+                       keyboardState.AltDown() );
+
     m_skip_heuristics = true;
     selectPoint( m_originalCursor, false, &m_canceledMenu );
     m_skip_heuristics = false;
@@ -1361,7 +1366,7 @@ void PCB_SELECTION_TOOL::selectAllItemsOnSheet( wxString& aSheetPath )
         if( aSheetPath.IsEmpty() )
             aSheetPath += '/';
 
-        if( footprint_path == aSheetPath )
+        if( footprint_path.StartsWith( aSheetPath ) )
             footprintList.push_back( footprint );
     }
 
@@ -1484,11 +1489,8 @@ int PCB_SELECTION_TOOL::selectSheetContents( const TOOL_EVENT& aEvent )
 
 int PCB_SELECTION_TOOL::selectSameSheet( const TOOL_EVENT& aEvent )
 {
-    if( !selectCursor( true ) )
-        return 0;
-
     // this function currently only supports footprints since they are only on one sheet.
-    auto item = m_selection.Front();
+    EDA_ITEM* item = m_selection.Front();
 
     if( !item )
         return 0;
@@ -1863,7 +1865,7 @@ bool PCB_SELECTION_TOOL::doSelectionMenu( GENERAL_COLLECTOR* aCollector )
             BOARD_ITEM* item = ( *aCollector )[i];
             text             = item->GetSelectMenuText( m_frame->GetUserUnits() );
 
-            wxString menuText = wxString::Format( "&%d. %s\t%d", i + 1, text, i + 1 );
+            wxString menuText = wxString::Format( wxT( "&%d. %s\t%d" ), i + 1, text, i + 1 );
             menu.Add( menuText, i + 1, item->GetMenuImage() );
         }
 
@@ -1991,6 +1993,24 @@ bool PCB_SELECTION_TOOL::Selectable( const BOARD_ITEM* aItem, bool checkVisibili
 {
     const RENDER_SETTINGS* settings = getView()->GetPainter()->GetSettings();
 
+    auto visibleLayers =
+            [&]()
+            {
+                if( m_isFootprintEditor )
+                {
+                    LSET set;
+
+                    for( PCB_LAYER_ID layer : LSET::AllLayersMask().Seq() )
+                        set.set( layer, view()->IsLayerVisible( layer ) );
+
+                    return set;
+                }
+                else
+                {
+                    return board()->GetVisibleLayers();
+                }
+            };
+
     if( settings->GetHighContrast() )
     {
         std::set<unsigned int> activeLayers = settings->GetHighContrastLayers();
@@ -2064,6 +2084,7 @@ bool PCB_SELECTION_TOOL::Selectable( const BOARD_ITEM* aItem, bool checkVisibili
     const ZONE*    zone = nullptr;
     const PCB_VIA* via = nullptr;
     const PAD*     pad = nullptr;
+    const FP_TEXT* text = nullptr;
 
     switch( aItem->Type() )
     {
@@ -2084,7 +2105,7 @@ bool PCB_SELECTION_TOOL::Selectable( const BOARD_ITEM* aItem, bool checkVisibili
         }
 
         // zones can exist on multiple layers!
-        if( !( zone->GetLayerSet() & board()->GetVisibleLayers() ).any() )
+        if( !( zone->GetLayerSet() & visibleLayers() ).any() )
             return false;
 
         break;
@@ -2114,7 +2135,7 @@ bool PCB_SELECTION_TOOL::Selectable( const BOARD_ITEM* aItem, bool checkVisibili
         via = static_cast<const PCB_VIA*>( aItem );
 
         // For vias it is enough if only one of its layers is visible
-        if( !( board()->GetVisibleLayers() & via->GetLayerSet() ).any() )
+        if( !( visibleLayers() & via->GetLayerSet() ).any() )
             return false;
 
         break;
@@ -2122,6 +2143,11 @@ bool PCB_SELECTION_TOOL::Selectable( const BOARD_ITEM* aItem, bool checkVisibili
     case PCB_FP_TEXT_T:
         if( m_isFootprintEditor )
         {
+            text = static_cast<const FP_TEXT*>( aItem );
+
+            if( !text->IsVisible() && !view()->IsLayerVisible( LAYER_MOD_TEXT_INVISIBLE ) )
+                return false;
+
             if( !view()->IsLayerVisible( aItem->GetLayer() ) )
                 return false;
         }
@@ -2175,7 +2201,7 @@ bool PCB_SELECTION_TOOL::Selectable( const BOARD_ITEM* aItem, bool checkVisibili
 
             // A pad's hole is visible on every layer the pad is visible on plus many layers the
             // pad is not visible on -- so we only need to check for any visible hole layers.
-            if( !( board()->GetVisibleLayers() & LSET::PhysicalLayersMask() ).any() )
+            if( !( visibleLayers() & LSET::PhysicalLayersMask() ).any() )
                 return false;
         }
         else
@@ -2186,7 +2212,7 @@ bool PCB_SELECTION_TOOL::Selectable( const BOARD_ITEM* aItem, bool checkVisibili
             else if( pad->IsOnLayer( B_Cu ) && !board()->IsElementVisible( LAYER_PAD_BK ) )
                 return false;
 
-            if( !( pad->GetLayerSet() & board()->GetVisibleLayers() ).any() )
+            if( !( pad->GetLayerSet() & visibleLayers() ).any() )
                 return false;
         }
 
@@ -2542,7 +2568,7 @@ void PCB_SELECTION_TOOL::GuessSelectionCandidates( GENERAL_COLLECTOR& aCollector
             }
             catch( const ClipperLib::clipperException& e )
             {
-                wxLogError( "A clipper exception %s was detected.", e.what() );
+                wxLogError( wxT( "A clipper exception %s was detected." ), e.what() );
             }
         }
 
